--
-- DynamicLoadInfo
-- Specialization for changing position of load info index (more realistic loading, like the scrap floor is moving)
--
-- @author  Stefan Maurus
-- @date  2015-03-12

-- Copyright  Stefan Maurus, www.stefanmaurus.de


DynamicLoadInfo = {};

function DynamicLoadInfo.prerequisitesPresent(specializations)
    return true;
end;

function DynamicLoadInfo:load(savegame)
    self.dynamicLoadInfo = {};
    self.dynamicLoadInfo.index = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.dynamicLoadInfo#index"));
    self.dynamicLoadInfo.position = {getTranslation(self.dynamicLoadInfo.index)};
    self.dynamicLoadInfo.startZ = getXMLFloat(self.xmlFile, "vehicle.dynamicLoadInfo#startZ");
    setTranslation(self.dynamicLoadInfo.index, self.dynamicLoadInfo.position[1], self.dynamicLoadInfo.position[2],self.dynamicLoadInfo.startZ);
    self.dynamicLoadInfo.endZ = getXMLFloat(self.xmlFile, "vehicle.dynamicLoadInfo#endZ");
    self.dynamicLoadInfo.step = getXMLFloat(self.xmlFile, "vehicle.dynamicLoadInfo#step");
    self.dynamicLoadInfo.height = getXMLFloat(self.xmlFile, "vehicle.dynamicLoadInfo#height");
end;

function DynamicLoadInfo:delete()
end;

function DynamicLoadInfo:mouseEvent(posX, posY, isDown, isUp, button)
end;

function DynamicLoadInfo:keyEvent(unicode, sym, modifier, isDown)
end;

function DynamicLoadInfo:update(dt)
    if self.tipState == 0 then --closed
        local xW,yW,zW = getWorldTranslation(self.dynamicLoadInfo.index);
        local xW, _, zW = worldToLocal(self.fillVolumes[1].volume, xW, yW, zW);
        local height = getFillPlaneHeightAtLocalPos(self.fillVolumes[1].volume, xW, zW);
        if height >= self.dynamicLoadInfo.height then
            local _,_,z = getTranslation(self.dynamicLoadInfo.index);
            setTranslation(self.dynamicLoadInfo.index, self.dynamicLoadInfo.position[1], self.dynamicLoadInfo.position[2], math.max(z-self.dynamicLoadInfo.step, self.dynamicLoadInfo.endZ));
            local _,_,z = getTranslation(self.dynamicLoadInfo.index);
            if z == self.dynamicLoadInfo.endZ then
                setTranslation(self.dynamicLoadInfo.index, self.dynamicLoadInfo.position[1], self.dynamicLoadInfo.position[2], self.dynamicLoadInfo.startZ);
            end;
        end;
    else --open flap
        local _,_,z = getTranslation(self.dynamicLoadInfo.index);
        if z ~= self.dynamicLoadInfo.startZ then
            setTranslation(self.dynamicLoadInfo.index, self.dynamicLoadInfo.position[1], self.dynamicLoadInfo.position[2], self.dynamicLoadInfo.startZ);
        end;
    end;
end;

function DynamicLoadInfo:updateTick(dt)
 end;

function DynamicLoadInfo:onAttach()
end;

function DynamicLoadInfo:onDetach()
end;

function DynamicLoadInfo:draw()
end;
-- converted