--
-- HydraulicPipes
-- Specialization for hydraulic pipes made with bones
--
-- @author  Stefan Maurus
-- @date  04/06/14

-- Copyright  Stefan Maurus, www.stefanmaurus.de

--[[
    <hydraulicPipes>
        <pipe index="INDEX" />
        <pipe index="INDEX" isAttached="true"/>
        <pipe index="INDEX" isDetached="true"/>
    </hydraulicPipes>
]]

HydraulicPipes = {};

function HydraulicPipes.prerequisitesPresent(specializations)
    return true;
end;

function HydraulicPipes:load(savegame)
    local i = 0;
    self.hydraulicPipes = {};
    while true do
        local key = string.format("vehicle.hydraulicPipes.pipe(%d)", i);
        if not hasXMLProperty(self.xmlFile, key) then
            break;
        end;
        local node = Utils.indexToObject(self.components, getXMLString(self.xmlFile, key.."#index"));
        local isAttached = Utils.getNoNil(getXMLBool(self.xmlFile, key.."#isAttached"), false);
        if isAttached then
            setVisibility(node, false);
        end;
        local isDetached = Utils.getNoNil(getXMLBool(self.xmlFile, key.."#isDetached"), false);
        if node ~= nil then
            table.insert(self.hydraulicPipes, {node=node, isAttached=isAttached, isDetached=isDetached});
        end;
        i = i + 1;
    end;
    for _, pipe in pairs(self.hydraulicPipes) do
        link(getRootNode(), pipe.node);
    end;
end;

function HydraulicPipes:delete()
    for _, pipe in pairs(self.hydraulicPipes) do
        delete(pipe.node);
    end;
end;

function HydraulicPipes:mouseEvent(posX, posY, isDown, isUp, button)
end;

function HydraulicPipes:keyEvent(unicode, sym, modifier, isDown)
end;

function HydraulicPipes:update(dt)
end;

function HydraulicPipes:updateTick(dt)
 end;

function HydraulicPipes:onAttach()
    for _, pipe in pairs(self.hydraulicPipes) do
        if pipe.isAttached then
            setVisibility(pipe.node, true);
        elseif pipe.isDetached then
            setVisibility(pipe.node, false);
        end;
    end;
end;

function HydraulicPipes:onDetach()
    for _, pipe in pairs(self.hydraulicPipes) do
        if pipe.isAttached then
            setVisibility(pipe.node, false);
        elseif pipe.isDetached then
            setVisibility(pipe.node, true);
        end;
    end;
end;

function HydraulicPipes:draw()
end;
-- converted